/**
    @file ft51_general_config_set_system_clock.c

    @brief General Configuration Library API set system clock function.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */
#include <stdlib.h>
#include <stdint.h>
#include "ft51_general_config.h"
#include "ft51_io_registers.h"
#include "registers/ft51_registers.h"

/**
 @brief          set_system_clock
 @details        Sets the system clock to either 6, 12, 24, or 48 MHz.

 @param[in]      system_clock    Frequency to set the clock to.
 **/
void set_system_clock(const FT51_SYSTEM_CLOCK system_clock)
{
    uint8_t value;

    IO_REG_GENERAL_READ(SYSTEM_CLOCK_DIVIDER, value);
    value = value & ~MASK_CLK_SYS_DIVISOR;

    switch (system_clock)
    {
    case FT51_48MHZ:
        value |= 0x00;
        break;
    case FT51_24MHZ:
        value |= 0x02;
        break;
    case FT51_12MHZ:
        value |= 0x04;
        break;
    case FT51_6MHZ:
    default:
        value |= 0x06;
        break;
    }

    IO_REG_GENERAL_WRITE(SYSTEM_CLOCK_DIVIDER, value);
}