/**
    @file ft51_spim_configure_slave.c

    @brief SPI Master Library API configure function.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */
#include <stdint.h>
#include "ft51_iomux.h"
#include "ft51_spim.h"

void SPIM_configure_slave(IOMUX_OUT_SIGNAL  output_signal, 
						  uint8_t 			idle_state,
                          SPIM_BIT_ORDER    bit_order, 
                          uint8_t           clock_divisor, 
                          SPIM_MODE         clock_mode, 
                          uint8_t           clock_delay)
{
    uint8_t slave_setup;
    uint8_t active_slave;
    
    SPIM_CLK(clock_divisor); // SCLK is division of FT51 system clock
    SPIM_SS_SETUP(idle_state, output_signal); // SS Idle State, SS number
    SPIM_SETTINGS(clock_mode, bit_order); // mode, order
    SPIM_DELAY(clock_delay); // delay between SS and first SCK cycle

    // IOMUX_OUT_SPI_MASTER_SS_N_x enumerations are in reverse order:
    // N_3, N_2, N_1, N_0, so subtract from N_0 to map into 0-3 range.
    active_slave = IOMUX_OUT_SPI_MASTER_SS_N_0 - output_signal;

    IO_REG_GENERAL_READ(SPI_MASTER_SS_SETUP, slave_setup);
    slave_setup &= ~MASK_SPI_SS_ROUTE;
    slave_setup |= (active_slave << BIT_SPI_SS_ROUTE_0);
    
    SPIM_SS_OFF; // Ensure slave is initially not selected.
}